import React, { Component } from 'react';
import {Footer, Header, Main} from '../src/components';
import {QRScan, Language, CheckinDocument, CheckinSelf, Location, ContactSearch } from '../src/components';
import AppStore from "./stores/AppStore";
import DesignStore from "./stores/DesignStore";

class App extends Component {
  constructor(props) {
    super(props);

    this.state = {
      display: AppStore.getDisplay(),
      action: AppStore.getAction(),
      designs: DesignStore.getDesign()
    };
    this.changeAction = this.changeAction.bind(this);
    this.update = this.update.bind(this);

    this.resetTimer = null;
   }

   reset(){
     if(this.state.designs !== undefined && this.state.designs["timer"] !== null &&  this.state.designs["timer"] !== undefined){
       var t = this.state.designs["timer"] * 1 ;
       if(t > 0){
         clearTimeout(this.resetTimer);
         this.resetTimer = setTimeout(function(){
           window.location.reload();
         }, 1000 * t);
       }
     }
   }

  eventHandler(e){
    this.setState({
      action:e.target.getAttribute('data-link')
    });
  }

  componentDidMount (){
    DesignStore.on("design_loaded", this.update);
    AppStore.on("change_action", this.changeAction);

    window.$(document).on("keydown", "*", function() {
      this.reset();
     }.bind(this));

    window.$(document).on("click", "*", function() {
       this.reset();
     }.bind(this));
  }

  changeAction(){
    this.setState({
      action : AppStore.getAction()
    })
  }

  update(){
    this.setState({
      display : AppStore.getDisplay(),
      designs : DesignStore.getDesign()
    })
  }

  render() {
    let topStyles = null
    let footerStyles = null
    let mainStyles = null

    if(this.state.designs){
      mainStyles = {
        backgroundColor: this.state.designs["main_bg_color"],
      };
      topStyles = {
        backgroundColor: this.state.designs["top_bg_color"],
      };
      footerStyles = {
        backgroundColor: this.state.designs["bot_bg_color"],
      };
    }

    let action = this.state.action;
    let displayAction ="";

    switch (action) {
      case "QRScan":  displayAction = <QRScan />;
      break;
      case "Language":  displayAction = <Language />;
      break;
      case "CheckinDocument":  displayAction = <CheckinDocument />;
      break;
      case "CheckinSelf":  displayAction = <CheckinSelf />;
      break;
      case "Location":  displayAction = <Location />;
      break;
      case "ContactSearch":  displayAction = <ContactSearch />;
      break;
      default :  displayAction = <Main handler={this.eventHandler.bind(this)} />;
      break;
    }

    return (
      <div className="App container-fluid" style={mainStyles}>
        <div className="row" id="header" style={topStyles}>
          <div className="col" >
            <Header handler={this.eventHandler.bind(this)} />
          </div>
        </div>
        {displayAction}
        <div className="row" id="footer" style={footerStyles} >
          <div className="col" >
            <Footer display={this.state.display} />
          </div>
        </div>

      </div>
    );
  }
}

export default App;
